@@ -5,7 +5,7 @@ Devel::CheckLib;
 
 use strict;
 use vars qw($VERSION @ISA @EXPORT);
-$VERSION = '0.699_002';
+$VERSION = '0.699_001';
 use Config;
 
 use File::Spec;
@@ -13,7 +13,7 @@ use File::Temp;
 
 require Exporter;
 @ISA = qw(Exporter);
-@EXPORT = qw(assert_lib check_lib_or_exit check_lib);
+@EXPORT = qw(assert_lib check_lib_or_exit);
 
 # localising prevents the warningness leaking out of this module
 local $^W = 1;    # use warnings is a 5.6-ism
@@ -138,23 +138,6 @@ This can also be supplied on the command-line.
 
 =back
 
-If you need to perform know more than "does it link?" you can provide
-code to be compiled and run:
-
-=over
-
-=item function
-
-the body of the <main()> function.  If not provided C<return 0;> is
-used.
-
-=item prologue
-
-code to insert between the C<#include> of the headers and the
-definition of main.
-
-=back
-
 =head2 check_lib_or_exit
 
 This behaves exactly the same as C<assert_lib()> except that instead of
@@ -168,11 +151,6 @@ causing a CPAN Testers 'FAIL' report.  CPAN Testers should ignore this
 result -- which is what you want if an external library dependency is not
 available.
 
-=head2 check_lib
-
-This behaves exactly the same as C<assert_lib()> except that it is silent,
-returning false instead of dieing, or true otherwise.
-
 =cut
 
 sub check_lib_or_exit {
@@ -183,11 +161,6 @@ sub check_lib_or_exit {
     }
 }
 
-sub check_lib {
-    eval 'assert_lib(@_)';
-    return $@ ? 0 : 1;
-}
-
 sub assert_lib {
     my %args = @_;
     my (@libs, @libpaths, @headers, @incpaths);
@@ -202,11 +175,6 @@ sub assert_lib {
     @incpaths = (ref($args{incpath}) ? @{$args{incpath}} : $args{incpath}) 
         if $args{incpath};
 
-    # each entry is an arrayref containing:
-    # 0: arrayref of library search paths
-    # 1: arrayref of library names
-    my @link_cfgs = map [ \@libpaths, [ $_ ] ], @libs;
-
     # work-a-like for Makefile.PL's LIBS and INC arguments
     # if given as command-line argument, append to %args
     for my $arg (@ARGV) {
@@ -219,25 +187,13 @@ sub assert_lib {
             }
         }
     }
+
     # using special form of split to trim whitespace
     if(defined($args{LIBS})) {
-        if (ref $args{LIBS}) {
-	    foreach my $arg (@{$args{LIBS}}) {
-		my @sep = split ' ', $arg;
-		my @libs = map { /^-l(.+)$/ ? $1 : () } @sep;
-		my @paths = map { /^-L(.+)$/ ? $1 : () } @sep;
-		push @link_cfgs, [ \@paths, \@libs ];
-	    }
-	}
-	else {
-	    my @libs;
-	    my @paths;
-	    foreach my $arg (split(' ', $args{LIBS})) {
-		die("LIBS argument badly-formed: $arg\n") unless($arg =~ /^-l/i);
-		push @{$arg =~ /^-l/ ? \@libs : \@paths}, substr($arg, 2);
-	    }
-	    push @link_cfgs, map [ \@paths, [ $_ ] ], @libs;
-	}
+        foreach my $arg (split(' ', $args{LIBS})) {
+            die("LIBS argument badly-formed: $arg\n") unless($arg =~ /^-l/i);
+            push @{$arg =~ /^-l/ ? \@libs : \@libpaths}, substr($arg, 2);
+        }
     }
     if(defined($args{INC})) {
         foreach my $arg (split(' ', $args{INC})) {
@@ -251,14 +207,11 @@ sub assert_lib {
     my @wrongresult;
 
     # first figure out which headers we can't find ...
-    my @use_headers;
     for my $header (@headers) {
-        push @use_headers, $header;
         my($ch, $cfile) = File::Temp::tempfile(
             'assertlibXXXXXXXX', SUFFIX => '.c'
         );
-        print $ch qq{#include <$_>\n} for @use_headers;
-        print $ch qq{int main(void) { return 0; }\n};
+        print $ch qq{#include <$header>\nint main(void) { return 0; }\n};
         close($ch);
         my $exefile = File::Temp::mktemp( 'assertlibXXXXXXXX' ) . $Config{_exe};
         my @sys_cmd;
@@ -298,11 +251,9 @@ sub assert_lib {
         'assertlibXXXXXXXX', SUFFIX => '.c'
     );
     print $ch qq{#include <$_>\n} foreach (@headers);
-    print $ch "\n$args{prologue}\n" if $args{prologue};
     print $ch "int main(void) { ".($args{function} || 'return 0;')." }\n";
     close($ch);
-    for my $link_cfg ( @link_cfgs ) {
-	my ($paths, $libs) = @$link_cfg;
+    for my $lib ( @libs ) {
         my $exefile = File::Temp::mktemp( 'assertlibXXXXXXXX' ) . $Config{_exe};
         my @sys_cmd;
         if ( $Config{cc} eq 'cl' ) {                 # Microsoft compiler
@@ -310,24 +261,23 @@ sub assert_lib {
             my @libpath = map { 
                 q{/libpath:} . Win32::GetShortPathName($_)
             } @libpaths; 
-            # this is horribly sensitive to the order of arguments
             @sys_cmd = (
                 @cc,
                 $cfile,
-                ( map { "$_.lib" } @$libs ),
+                "${lib}.lib",
                 "/Fe$exefile", 
                 (map { '/I'.Win32::GetShortPathName($_) } @incpaths),
                 "/link",
-                (map {'/libpath:'.Win32::GetShortPathName($_)} @$paths),
+                (map {'/libpath:'.Win32::GetShortPathName($_)} @libpaths),
             );
         } elsif($Config{cc} eq 'CC/DECC') {          # VMS
         } elsif($Config{cc} =~ /bcc32(\.exe)?/) {    # Borland
             @sys_cmd = (
                 @cc,
                 "-o$exefile",
-                (map { "-l$_" } @$libs ),
+                "-l$lib",
                 (map { "-I$_" } @incpaths),
-                (map { "-L$_" } @$paths),
+                (map { "-L$_" } @libpaths),
                 $cfile);
         } else {                                     # Unix-ish
                                                      # gcc, Sun, AIX (gcc, cc)
@@ -335,15 +285,15 @@ sub assert_lib {
                 @cc,
                 $cfile,
                 "-o", "$exefile",
-                (map { "-l$_" } @$libs ),
+                "-l$lib",
                 (map { "-I$_" } @incpaths),
-                (map { "-L$_" } @$paths)
+                (map { "-L$_" } @libpaths)
             );
         }
         warn "# @sys_cmd\n" if $args{debug};
         my $rv = $args{debug} ? system(@sys_cmd) : _quiet_system(@sys_cmd);
-        push @missing, @$libs if $rv != 0 || ! -x $exefile;
-        push @wrongresult, @$libs if $rv == 0 && -x $exefile && system(File::Spec->rel2abs($exefile)) != 0; 
+        push @missing, $lib if $rv != 0 || ! -x $exefile;
+        push @wrongresult, $lib if $rv == 0 && -x $exefile && system(File::Spec->rel2abs($exefile)) != 0; 
         _cleanup_exe($exefile);
     } 
     unlink $cfile;
